estim.pi0(p, pi0.method = "ALL", nbins = 20, pz = 0.05)"st.boot", "st.spline", "langaas", "jiang", "histo", "pounds", "abh" or "slim""jiang" and "histo" methods. Default is 20."slim" method. Wang, Tuominen and Tsai (2011) suggest to take a value between 0.01 and 0.1. Default is 0.05.pi0.method="ALL"."abh" the least slope method proposed in Benjamini and Hochberg (2000).
"st.spline" the smoother method described in Storey and Tibshirani (2003).
The qvalue function of R package qvalue with default tuning is used (Storey (2015)).
"st.boot" the bootstrap method described in Storey et al. (2004).
The qvalue function of R package qvalue with default tuning is used (Storey (2015)).
"langaas" the method described in Langaas, Ferkingstad and Lindqvist (2005) using a convex
decreasing density estimate for p-values. The convest function of R package limma
with default tuning is used (Ritchie et al. (2015)).
"histo" the histogram method described in Nettleton, Hwang, Caldo and Wise (2006).
"pounds" the conservative estimate described in Pounds and Cheng (2006).
"jiang" the average estimate method described in Jiang and Doerge (2008).
"slim" the method of Wang, Tuominen and Tsai (2011) using a sliding linear model.
The default tuning suggested by Wang, Tuominen and Tsai (2011) is used.
Using their notations, lambda1 is fixed to 0.1, n to 10 and B to 100.
}calibration.plot, adjust.p#get p-values
data(LFQRatio2)
p=LFQRatio2[,7]
#estimate the proportion of true null hypotheses with different methods
r=estim.pi0(p)
r$pi0
#estimate the proportion of true null hypotheses with the "abh" method
r=estim.pi0(p, pi0.method="abh")
r$pi0
#compare with one minus the proportion of human proteins
prop_human=sum(LFQRatio2$Organism=="human")/length(LFQRatio2$Organism)
pi0_true=1-prop_human
pi0_trueRun the code above in your browser using DataLab